/***************************************************************************
                          kmuddocker.h
                      -------------------
    description          : This class docks in kpanel's tray, when the Kmud app is hidden
    begin                : Fri Jul 28 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef KMUDDOCKER_H
#define KMUDDOCKER_H

#include <qlabel.h>
#include <qpixmap.h>

/**
  *@author Kevin Krammer
  */

class KmudDocker : public QLabel  {
  Q_OBJECT

public: 
	KmudDocker(QWidget* kmud_app, const QPixmap& tray_icon);
	~KmudDocker();

public slots:
  virtual void mousePressEvent(QMouseEvent* event);

private:
  QWidget* kmud_app;
};

#endif
